Todo list

Logged in as: admin Project: theproject
This is list deliverance.
Reorder
Task name Status ↓ Deadline ↓ Assigned to↓ Created by

- nycsr
  not done 14 October, 2006 unassigned admin
  - debug
    not done admin admin
  - load test data
    not done unassigned admin

Add a new task.

List: |
Parent: |
Title: |
Description: |
Deadline: | hh:mm:ss
Private: |
Assign task to: |

Nevermind

Edit list settings | Back to list of lists